==> aws-android-sdk-textract-2.13.7-sources.jar: com/amazonaws/services/textract/model/transform/AnalyzeDocumentResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.textract.model.transform;

import com.amazonaws.services.textract.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response AnalyzeDocumentResult
 */
public class AnalyzeDocumentResultJsonUnmarshaller implements
        Unmarshaller<AnalyzeDocumentResult, JsonUnmarshallerContext> {

    public AnalyzeDocumentResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        AnalyzeDocumentResult analyzeDocumentResult = new AnalyzeDocumentResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("DocumentMetadata")) {
                analyzeDocumentResult.setDocumentMetadata(DocumentMetadataJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("Blocks")) {
                analyzeDocumentResult.setBlocks(new ListUnmarshaller<Block>(BlockJsonUnmarshaller
                        .getInstance()
                        )
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return analyzeDocumentResult;
    }

    private static AnalyzeDocumentResultJsonUnmarshaller instance;

    public static AnalyzeDocumentResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new AnalyzeDocumentResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-textract-2.16.10-sources.jar: com/amazonaws/services/textract/model/transform/AnalyzeDocumentResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.textract.model.transform;

import com.amazonaws.services.textract.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response AnalyzeDocumentResult
 */
public class AnalyzeDocumentResultJsonUnmarshaller implements
        Unmarshaller<AnalyzeDocumentResult, JsonUnmarshallerContext> {

    public AnalyzeDocumentResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        AnalyzeDocumentResult analyzeDocumentResult = new AnalyzeDocumentResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("DocumentMetadata")) {
                analyzeDocumentResult.setDocumentMetadata(DocumentMetadataJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("Blocks")) {
                analyzeDocumentResult.setBlocks(new ListUnmarshaller<Block>(BlockJsonUnmarshaller
                        .getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("HumanLoopActivationOutput")) {
                analyzeDocumentResult
                        .setHumanLoopActivationOutput(HumanLoopActivationOutputJsonUnmarshaller
                                .getInstance()
                                .unmarshall(context));
            } else if (name.equals("AnalyzeDocumentModelVersion")) {
                analyzeDocumentResult.setAnalyzeDocumentModelVersion(StringJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return analyzeDocumentResult;
    }

    private static AnalyzeDocumentResultJsonUnmarshaller instance;

    public static AnalyzeDocumentResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new AnalyzeDocumentResultJsonUnmarshaller();
        return instance;
    }
}
